@@ -10,39 +10,51 @@
 using namespace SimTK;
 
 template <class ResidueStretchType>
-
 class ResidueStretchContainer{
-    //private:
-    public:
+    protected:
     vector<ResidueStretchType> residueStretchVector;
+
+    public:
     InterfaceContainer interfaceContainer;
 
     ResidueStretchContainer() {};
 
     void clear(){residueStretchVector.clear();interfaceContainer.clear(); };
-    void validateResidueStretch(ResidueStretchType myResidueStretch, BiopolymerClassContainer & myBiopolymerClassContainer) {
-	if (myBiopolymerClassContainer.updBiopolymerClass(myResidueStretch.getChain()).difference(myResidueStretch.getEndResidue() , myResidueStretch.getStartResidue()) < 0) {
-	    ErrorManager::instance <<__FILE__<<":"<<__LINE__<<" The end residue (currently "<<myResidueStretch.getEndResidue().outString()
-		<<") must be greater than or equal to the start residue (currently "<<myResidueStretch.getStartResidue().outString()<<". "<<endl; ErrorManager::instance.treatError();
+    void validateResidueStretch(const ResidueStretchType & myResidueStretch, const BiopolymerClassContainer & myBiopolymerClassContainer) {
+	if (myBiopolymerClassContainer.getBiopolymerClass(myResidueStretch.getChain()).difference(myResidueStretch.getEndResidue() , myResidueStretch.getStartResidue()) < 0) {
+        MMBLOG_FILE_FUNC_LINE(CRITICAL, "The end residue (currently "<<myResidueStretch.getEndResidue().outString()
+		<<") must be greater than or equal to the start residue (currently "<<myResidueStretch.getStartResidue().outString()<<". "<<endl);
 	}
-	if ((myResidueStretch.getEndResidue() > myBiopolymerClassContainer.updBiopolymerClass(myResidueStretch.getChain()).getLastResidueID()) ) {
-	    ErrorManager::instance <<__FILE__<<":"<<__LINE__<<" The end residue (currently "<<myResidueStretch.getEndResidue().outString()
-		<<") is greater than the last residue number of the chain."<<endl; ErrorManager::instance.treatError();
+	if ((myResidueStretch.getEndResidue() > myBiopolymerClassContainer.getBiopolymerClass(myResidueStretch.getChain()).getLastResidueID()) ) {
+        MMBLOG_FILE_FUNC_LINE(CRITICAL, "The end residue (currently "<<myResidueStretch.getEndResidue().outString()
+		<<") is greater than the last residue number of the chain."<<endl);
 	}
-	if ((myResidueStretch.getStartResidue() < myBiopolymerClassContainer.updBiopolymerClass(myResidueStretch.getChain()).getFirstResidueID()) ) {
-	    ErrorManager::instance <<__FILE__<<":"<<__LINE__<<" The start residue (currently "<<myResidueStretch.getStartResidue().outString()
-		<<") is lesser than the first residue number of the chain."<<endl; ErrorManager::instance.treatError();
+	if ((myResidueStretch.getStartResidue() < myBiopolymerClassContainer.getBiopolymerClass(myResidueStretch.getChain()).getFirstResidueID()) ) {
+	    MMBLOG_FILE_FUNC_LINE(CRITICAL, "The start residue (currently "<<myResidueStretch.getStartResidue().outString()
+		<<") is lesser than the first residue number of the chain."<<endl);
 	}
 	if (!(myBiopolymerClassContainer.hasChainID(myResidueStretch.getChain()))){
-	    ErrorManager::instance <<__FILE__<<":"<<__LINE__<<" Couldn't find chain "<<myResidueStretch.getChain()<<endl; ErrorManager::instance.treatError();
+	    MMBLOG_FILE_FUNC_LINE(CRITICAL, "Couldn't find chain "<<myResidueStretch.getChain()<<endl);
 	}
     }
 
-    void addStretch(ResidueStretchType newStretch) {
-        residueStretchVector.push_back(newStretch);
-    }    
+    void add(const ResidueStretchType myResidueStretch, BiopolymerClassContainer & myBiopolymerClassContainer) {
+        validateResidueStretch(myResidueStretch,myBiopolymerClassContainer);
+	addStretch(myResidueStretch);
+    }
+    void addStretch(const ResidueStretchType & newStretch) {
+        MMBLOG_FILE_FUNC_LINE(DEBUG, " About to add a new stretch to the residueStretchVector, which currently has "<< getNumResidueStretches() << " elements."<<endl);
+        residueStretchVector.emplace_back(newStretch);
+        MMBLOG_FILE_FUNC_LINE(DEBUG, " Done adding  a new stretch to the residueStretchVector, which now has "<< getNumResidueStretches() << " elements."<<endl);
+    }
+    void addStretch(ResidueStretchType && newStretch) {
+        MMBLOG_FILE_FUNC_LINE(DEBUG, " About to add a new stretch to the residueStretchVector, which currently has "<< getNumResidueStretches() << " elements."<<endl);
+        residueStretchVector.emplace_back(std::move(newStretch));
+        MMBLOG_FILE_FUNC_LINE(DEBUG, " Done adding  a new stretch to the residueStretchVector, which now has "<< getNumResidueStretches() << " elements."<<endl);
+    }
 
-    vector<ResidueStretchType> getResidueStretchVector() {return residueStretchVector;};
+    const vector<ResidueStretchType> & getResidueStretchVector() const { return residueStretchVector; }
+          vector<ResidueStretchType> & updResidueStretchVector()       { return residueStretchVector; }
 
     void printResidueStretchVector() {
         for (int i = 0 ; i <residueStretchVector.size(); i++) {
@@ -67,19 +79,19 @@ class ResidueStretchContainer{
         return residueStretchVector[residueStretchIndex];
     };
 
-    const int getNumResidueStretches() { 
+    const int getNumResidueStretches() const { 
         //cout<<__FILE__<<":"<<__LINE__<<" residueStretchVector.size() = "<<residueStretchVector.size()<<endl;
         return residueStretchVector.size();
     }
 
     vector <MobilizerStretch> getMobilizerStretchVector(String bondMobilityString)  {
 		vector <MobilizerStretch> myMobilizerStretchVector;
-		for (int i = 0; i < (int)residueStretchVector.size(); i++){
-                        MobilizerStretch myMobilizerStretch ( residueStretchVector[i], bondMobilityString); 
-			myMobilizerStretchVector.push_back(myMobilizerStretch);
-              
-                        cout<<__FILE__<<":"<<__LINE__<<" For chain "<<myMobilizerStretch.getChain()<< " start res "<<myMobilizerStretch.getStartResidue().outString()<<" end res "<< myMobilizerStretch.getEndResidue().outString() <<" mobility " << myMobilizerStretch.getBondMobility()<<endl;//" and chain "<< targetChain<<" residue "<<targetResidue.outString()<<" distance is "<<myDistance<<" nm"<<endl;
-                        cout<< __FILE__<<":"<<__LINE__<<" Note that in prior releases of MMB we took dead lengths in Å.  For consistency with molmodel we are going back to nm, kJ/mol, ps, with apologies for the confusion."<<endl;
+		for (size_t i = 0; i < residueStretchVector.size(); i++) {
+			myMobilizerStretchVector.emplace_back(residueStretchVector[i], bondMobilityString);
+
+            const auto &back = myMobilizerStretchVector.back();
+            MMBLOG_FILE_FUNC_LINE(INFO, "For chain "<<back.getChain()<< " start res "<<back.getStartResidue().outString()<<" end res "<<back.getEndResidue().outString() <<" mobility " <<back.getBondMobility()<<endl);//" and chain "<< targetChain<<" residue "<<targetResidue.outString()<<" distance is "<<myDistance<<" nm"<<endl;
+            MMBLOG_FILE_FUNC_LINE(INFO, "Note that in prior releases of MMB we took dead lengths in Å.  For consistency with molmodel we are going back to nm, kJ/mol, ps, with apologies for the confusion."<<endl);
 
 		}
 		return myMobilizerStretchVector;
@@ -109,9 +121,10 @@ class ResidueStretchContainer{
         return residueStretchVector.end();
     }
 
-	void addResidueStretchToVector(ResidueStretchType & residueStretch)
+    // Really this member should just be deleted in favor of addStretch
+    void addResidueStretchToVector(ResidueStretchType & residueStretch)
     {
-        residueStretchVector.push_back(residueStretch);
+        addStretch(residueStretch);
     }
 
     void removeResidueStretchFromVector(ResidueStretchType & residueStretch)
@@ -121,8 +134,7 @@ class ResidueStretchContainer{
             residueStretchVector.erase(it);
         else
         {
-            ErrorManager::instance <<__FILE__<<":"<<__LINE__<<": you tried to delete a non existing ResidueStretch: "<<"Stretch chain ="<< residueStretch.getChain()<<", first residue ="<<residueStretch.getStartResidue().outString()<<", last residue ="<<residueStretch.getEndResidue().outString()<< endl;
-            ErrorManager::instance.treatError();
+            MMBLOG_FILE_FUNC_LINE(CRITICAL, "you tried to delete a non existing ResidueStretch: "<<"Stretch chain ="<< residueStretch.getChain()<<", first residue ="<<residueStretch.getStartResidue().outString()<<", last residue ="<<residueStretch.getEndResidue().outString()<< endl);
         }
     }
 
@@ -132,8 +144,7 @@ class ResidueStretchContainer{
             residueStretchVector.erase(residueStretchVector.begin()+id);
         else
         {
-            ErrorManager::instance <<__FILE__<<":"<<__LINE__<<": you tried to delete a non existing ResidueStretch." << endl;
-            ErrorManager::instance.treatError();
+            MMBLOG_FILE_FUNC_LINE(CRITICAL, "you tried to delete a non existing ResidueStretch." << endl);
         }
     }
 
@@ -155,8 +166,8 @@ class ResidueStretchContainer{
 	                    	targetBiopolymerClass.calcDefaultAtomLocationInGroundFrame  ( targetResidue, targetBiopolymerClass.getRepresentativeAtomName())
                     		- referenceBiopolymerClass.calcDefaultAtomLocationInGroundFrame(referenceResidue, referenceBiopolymerClass.getRepresentativeAtomName())
                     	).norm(); // *10; // convert to Å -- no longer done, now using nm directly
-                cout<<__FILE__<<":"<<__LINE__<<" For chain "<<referenceChain<<" residue "<<referenceResidue.outString()<<" and chain "<< targetChain<<" residue "<<targetResidue.outString()<<" distance is "<<myDistance<<" nm "<<endl;
-                cout<< __FILE__<<":"<<__LINE__<<" Note that in prior releases of MMB we took distances in Å.  For consistency with molmodel we are going back to nm, kJ/mol, ps, with apologies for the confusion."<<endl;
+                MMBLOG_FILE_FUNC_LINE(INFO, "For chain "<<referenceChain<<" residue "<<referenceResidue.outString()<<" and chain "<< targetChain<<" residue "<<targetResidue.outString()<<" distance is "<<myDistance<<" nm "<<endl);
+                MMBLOG_FILE_FUNC_LINE(INFO, "Note that in prior releases of MMB we took distances in Å. For consistency with molmodel we are going back to nm, kJ/mol, ps, with apologies for the confusion."<<endl);
                 return myDistance;
 	};
 				
@@ -168,12 +179,11 @@ class ResidueStretchContainer{
                 String referenceChain = referenceBiopolymerClass.getChainID(); 
                 String targetChain = targetBiopolymerClass.getChainID(); 
 		if (referenceBiopolymerClass.getChainID().compare(targetBiopolymerClass.getChainID()) == 0) {
-			ErrorManager::instance <<__FILE__<<":"<<__LINE__<<" Chain "<<referenceChain<<" can't have an interface with itself!"<<endl;
-			ErrorManager::instance.treatError();
+			MMBLOG_FILE_FUNC_LINE(CRITICAL, "Chain "<<referenceChain<<" can't have an interface with itself!"<<endl);
 		};
-			residueStretchVector.push_back(ResidueStretchType(targetChain, targetResidue, targetResidue));
+                residueStretchVector.emplace_back(targetChain, targetResidue, targetResidue);
                 
-		cout<<__FILE__<<":"<<__LINE__<<" Chain "<<targetChain<<" residue "<<targetResidue.outString()<<" added to interface mobility zone. "<<endl;
+		MMBLOG_FILE_FUNC_LINE(INFO, "Chain "<<targetChain<<" residue "<<targetResidue.outString()<<" added to interface mobility zone. "<<endl);
 	};
 
 
@@ -198,7 +208,7 @@ class ResidueStretchContainer{
 		for (int i = 0; i < interfaceContainer.numInterfaces(); i++) {
 			Interface tempInterface = interfaceContainer.getInterface(i);
 			addAllMutualChainResidues(tempInterface.Depth, tempInterface.Chains, tempInterface.PartnerChains, myBiopolymerClassContainer);
-			cout<<__FILE__<<":"<<__LINE__<<endl;
+            MMBLOG_FILE_FUNC_LINE(INFO, endl);
 		}
 	};
 
@@ -253,13 +263,13 @@ class ResidueStretchContainer{
                     myResidueStretch2.setStartResidue(concatenatedAtomInfoVector[neighborList[j].second].residueID);
                     myResidueStretch2.setEndResidue(concatenatedAtomInfoVector[neighborList[j].second].residueID);
                     myResidueStretch2.setChain(concatenatedAtomInfoVector[neighborList[j].second].chain);
-                    if (!(vectorHasResidueStretch(myResidueStretch1))) {addResidueStretchToVector(myResidueStretch1);
-			cout<<__FILE__<<":"<<__LINE__<<" Added first residue stretch"<<endl; 
+                    if (!(vectorHasResidueStretch(myResidueStretch1))) {addStretch(myResidueStretch1);
+			        MMBLOG_FILE_FUNC_LINE(INFO, "Added first residue stretch"<<endl);
                         myResidueStretch1.printStretch();
                         //print (myResidueStretch1);
 		    }
-                    if (!(vectorHasResidueStretch(myResidueStretch2))) {addResidueStretchToVector(myResidueStretch2);
-			cout<<__FILE__<<":"<<__LINE__<<" Added second residue stretch"<<endl; 
+                    if (!(vectorHasResidueStretch(myResidueStretch2))) {addStretch(myResidueStretch2);
+			            MMBLOG_FILE_FUNC_LINE(INFO, "Added second residue stretch"<<endl);
                         myResidueStretch2.printStretch() ;
                     }
 	  	}
@@ -270,53 +280,6 @@ class ResidueStretchContainer{
 	};
         #endif
 	
-/*
-	void addSingleWeldConstraintPerInterfaceChainPair( double radius, //vector<String> referenceChains, vector<String> partnerChains , ConstraintContainer & myConstraintContainer,  
-            BiopolymerClassContainer & myBiopolymerClassContainer) { // This polymorphism requires that the user specify two sets of chains.  Only residues at the interface between the two sets will be included.  This lets the user leave out other chains (e.g. threading templates) which are in the system but which shouldn't be flexibilized.
-            vector<MMBAtomInfo> concatenatedAtomInfoVector = myBiopolymerClassContainer.getConcatenatedAtomInfoVector();
-	    vector<openmmVecType> particleList(concatenatedAtomInfoVector.size());
-            for (int i = 0; i < concatenatedAtomInfoVector.size() ; i++) {
- 		particleList[i] = concatenatedAtomInfoVector[i].position;
-	    }
-            cout<<__FILE__<<":"<<__LINE__<<endl;
-	    vector<set<int> > exclusions( particleList.size() );
-	    OpenMM::NeighborList neighborList;
-            openmmVecType boxSize = openmmVecType(10000,10000,10000);
-            cout<<__FILE__<<":"<<__LINE__<<" neighborList size is : "<<neighborList.size()<<endl;
-	    computeNeighborListVoxelHash(neighborList, particleList.size() , particleList, exclusions, &boxSize, false, radius  , 0.0);
-            //cout<<__FILE__<<":"<<__LINE__<<" neighborList size is : "<<neighborList.size()<<endl;
-            //cout<<__FILE__<<":"<<__LINE__<<" neighborList size is : "<<neighborList.size()<<endl;
-            for ( int j = 0 ; j < neighborList.size(); j++) {
-                //cout<<__FILE__<<":"<<__LINE__<<" concatenatedAtomInfoVector[neighborList[j].first].chain ="<<concatenatedAtomInfoVector[neighborList[j].first].chain<< " ";
-                //cout<<__FILE__<<":"<<__LINE__<<" concatenatedAtomInfoVector[neighborList[j].second].chain ="<<concatenatedAtomInfoVector[neighborList[j].second].chain<<endl;
-                if (((( vectorCompare(concatenatedAtomInfoVector[neighborList[j].first].chain , (referenceChains))) == 1) &&
-                     (( vectorCompare(concatenatedAtomInfoVector[neighborList[j].second].chain ,(  partnerChains))) == 1))  != //Use an XOR here. This means if the 'partnerChains' evaluation is later set to return 1 when partnerChains is empty, this will still work.
-                    ((( vectorCompare(concatenatedAtomInfoVector[neighborList[j].second].chain ,(referenceChains))) == 1) &&
-                     (( vectorCompare(concatenatedAtomInfoVector[neighborList[j].first].chain  ,(  partnerChains))) == 1))     //Make sure that exactly one residue is in the 'referenceChains', and the other residue is in the 'partnerChains' .. thus only the desired interface is included
-															  )  
-                 
-		{
-		    //cout<<__FILE__<<":"<<__LINE__<<endl;
-                    ResidueID residueID1(concatenatedAtomInfoVector[neighborList[j].first].residueID);
-                    String chain1(concatenatedAtomInfoVector[neighborList[j].first].chain);
-                    String atom1(concatenatedAtomInfoVector[neighborList[j].first].atomName);
-                    ResidueID residueID2(concatenatedAtomInfoVector[neighborList[j].second].residueID);
-                    String chain2(concatenatedAtomInfoVector[neighborList[j].second].chain);
-                    String atom2(concatenatedAtomInfoVector[neighborList[j].second].atomName);
-	   	    if (!(myConstraintContainer.hasConstraintClass(myResidueStretch1.getChain(),myResidueStretch2.getChain()))) {
-                        ConstraintClass myConstraintClass(chain1 ,residueID1,atom1,chain2, residueID2,atom2, ConstraintType::WeldToAtom);
-		        myConstraintContainer.addConstraintClassToVector(myConstraintClass);
-		        cout<<__FILE__<<":"<<__LINE__<<" Added ConstraintClass :"<<endl; 
-		        myConstraintClass.print();
-                        // Right here, should probably delete particleList  element.
-		    }
-	  	}
-                else {
-                    // Right here, should probably delete particleList element.
-                }
-            }
-	};
-*/
     #ifdef USE_OPENMM
     void addIntraChainInterfaceResidues(double radius, String referenceChain, BiopolymerClassContainer & myBiopolymerClassContainer) { // This polymorphism requires that the user specify ONE  chain.  Only residues at the interfaces between BODIES on that chain will be included.  This does NOT include interfaces with OTHER chains. 
             vector<MMBAtomInfo> chainAtomInfoVector = myBiopolymerClassContainer.updBiopolymerClass(referenceChain).getAtomInfoVector();
@@ -332,19 +295,19 @@ class ResidueStretchContainer{
 	    ////openmmVecType * boxSize ;
             //*boxSize = openmmVecType(10000,10000,10000);
             openmmVecType boxSize = openmmVecType(10000,10000,10000);
-            cout<<__FILE__<<":"<<__LINE__<<" neighborList size is : "<<neighborList.size()<<endl;
+            MMBLOG_FILE_FUNC_LINE(INFO, "neighborList size is : "<<neighborList.size()<<endl);
 	    computeNeighborListVoxelHash(neighborList, particleList.size() , particleList, exclusions, &boxSize, false, radius  , 0.0);
-            cout<<__FILE__<<":"<<__LINE__<<" in addIntraChainInterfaceResidues. About to add residues to physics zone." <<endl;
-            cout<<__FILE__<<":"<<__LINE__<<" neighborList size is : "<<neighborList.size()<<endl;
-            cout<<__FILE__<<":"<<__LINE__<<" depth = "<< radius <<endl;
-            cout<<__FILE__<<":"<<__LINE__<<" chain = "<< referenceChain <<endl;
+            MMBLOG_FILE_FUNC_LINE(INFO, "in addIntraChainInterfaceResidues. About to add residues to physics zone." <<endl);
+            MMBLOG_FILE_FUNC_LINE(INFO, "neighborList size is : "<<neighborList.size()<<endl);
+            MMBLOG_FILE_FUNC_LINE(INFO, "depth = "<< radius <<endl);
+            MMBLOG_FILE_FUNC_LINE(INFO, "chain = "<< referenceChain <<endl);
             for ( int j = 0 ; j < neighborList.size(); j++) {
                 if (chainAtomInfoVector[neighborList[j].first].mobilizedBodyIndex < 0) {
-		    ErrorManager::instance <<__FILE__<<":"<<__LINE__<<" Bad chainAtomInfoVector[neighborList[j].first].mobilizedBodyIndex = " <<chainAtomInfoVector[neighborList[j].first].mobilizedBodyIndex <<endl; 
-		    ErrorManager::instance.treatError(); }
+		            MMBLOG_FILE_FUNC_LINE(CRITICAL, "Bad chainAtomInfoVector[neighborList[j].first].mobilizedBodyIndex = " <<chainAtomInfoVector[neighborList[j].first].mobilizedBodyIndex <<endl);
+		        }
                 if (chainAtomInfoVector[neighborList[j].second].mobilizedBodyIndex < 0) {
-		    ErrorManager::instance <<__FILE__<<":"<<__LINE__<<" Bad chainAtomInfoVector[neighborList[j].second].mobilizedBodyIndex = " <<chainAtomInfoVector[neighborList[j].second].mobilizedBodyIndex <<endl; 
-		    ErrorManager::instance.treatError(); }
+		            MMBLOG_FILE_FUNC_LINE(CRITICAL, "Bad chainAtomInfoVector[neighborList[j].second].mobilizedBodyIndex = " <<chainAtomInfoVector[neighborList[j].second].mobilizedBodyIndex <<endl);
+		        }
                 if (( chainAtomInfoVector[neighborList[j].first].mobilizedBodyIndex != chainAtomInfoVector[neighborList[j].second].mobilizedBodyIndex )) // &&  // if the two atoms belong to separate bodies, include them in the physics zone
                     //( chainAtomInfoVector[neighborList[j].first].chain.compare( referenceChain ) == 0) &&                                                   // the two atoms should also be in referenceChain
                     //( chainAtomInfoVector[neighborList[j].second].chain.compare( referenceChain ) == 0) ) 
@@ -359,29 +322,29 @@ class ResidueStretchContainer{
                     //myResidueStretch2.setEndResidue(chainAtomInfoVector[neighborList[j].second].residueID);
                     myResidueStretch2.setChain(chainAtomInfoVector[neighborList[j].second].chain);
                     if (!(vectorHasResidueStretch(myResidueStretch1))) {addResidueStretchToVector(myResidueStretch1);
-			cout<<__FILE__<<":"<<__LINE__<<" Added first residue stretch"<<endl; 
+			            MMBLOG_FILE_FUNC_LINE(INFO, "Added first residue stretch"<<endl);
                         myResidueStretch1.printStretch();
-                        cout<<__FILE__<<":"<<__LINE__<<" based on chainAtomInfoVector["<<neighborList[j].first<<"].print() "<<endl; chainAtomInfoVector[neighborList[j].first].print();
-                        cout<<__FILE__<<":"<<__LINE__<<" based on chainAtomInfoVector["<<neighborList[j].second<<"].print() "<<endl; chainAtomInfoVector[neighborList[j].second].print();
+                        MMBLOG_FILE_FUNC_LINE(INFO, "based on chainAtomInfoVector["<<neighborList[j].first<<"].print() "<<endl); chainAtomInfoVector[neighborList[j].first].print();
+                        MMBLOG_FILE_FUNC_LINE(INFO, "based on chainAtomInfoVector["<<neighborList[j].second<<"].print() "<<endl); chainAtomInfoVector[neighborList[j].second].print();
                         if (myResidueStretch1.getChain().compare(referenceChain) != 0) {
-			    ErrorManager::instance <<__FILE__<<":"<<__LINE__<<" Added undesired chain = "<<myResidueStretch1.getChain()<<endl;
-			    ErrorManager::instance.treatError(); }
+			                MMBLOG_FILE_FUNC_LINE(CRITICAL, "Added undesired chain = "<<myResidueStretch1.getChain()<<endl);
+			            }
 		    } // of if
                     if (!(vectorHasResidueStretch(myResidueStretch2))) {addResidueStretchToVector(myResidueStretch2);
-			cout<<__FILE__<<":"<<__LINE__<<" Added second residue stretch"<<endl; 
-                        cout<<__FILE__<<":"<<__LINE__<<" based on chainAtomInfoVector["<<neighborList[j].first<<"].print() "<<endl; chainAtomInfoVector[neighborList[j].first].print();
-                        cout<<__FILE__<<":"<<__LINE__<<" based on chainAtomInfoVector["<<neighborList[j].second<<"].print() "<<endl; chainAtomInfoVector[neighborList[j].second].print();
+			            MMBLOG_FILE_FUNC_LINE(INFO, "Added second residue stretch"<<endl);
+                        MMBLOG_FILE_FUNC_LINE(INFO, "based on chainAtomInfoVector["<<neighborList[j].first<<"].print() "<<endl); chainAtomInfoVector[neighborList[j].first].print();
+                        MMBLOG_FILE_FUNC_LINE(INFO, "based on chainAtomInfoVector["<<neighborList[j].second<<"].print() "<<endl); chainAtomInfoVector[neighborList[j].second].print();
                         myResidueStretch2.printStretch();
                         if (myResidueStretch2.getChain().compare(referenceChain) != 0) {
-			    ErrorManager::instance <<__FILE__<<":"<<__LINE__<<" Added undesired chain = "<<myResidueStretch2.getChain()<<endl;
-			    ErrorManager::instance.treatError(); }
+			                MMBLOG_FILE_FUNC_LINE(CRITICAL, "Added undesired chain = "<<myResidueStretch2.getChain()<<endl);
+			            }
                     }
 	  	}
                 else {
                     //  It seems unnecessary to actually delete the neighborList elements.  It should be enough not to call addResidueStretchToVector.
                 }
             }
-            cout<<__FILE__<<":"<<__LINE__<<" done with addIntraChainInterfaceResidues. " <<endl;
+            MMBLOG_FILE_FUNC_LINE(INFO, "done with addIntraChainInterfaceResidues. " <<endl);
 	};
     #endif
 
