@@ -11,7 +11,7 @@
 #include "BasePairContainer.h"
 #include "BiopolymerClass.h"
 #include "Utils.h"          
-
+#include "NtC_Class_Container.h"
 #include <sstream>
 
 void BasePairContainer::clear(){
@@ -26,7 +26,7 @@ void BasePairContainer::addBasePair(BiopolymerClassContainer & myBiopolymerClass
 }
 
 void BasePairContainer::deleteBasePair(int basePairIndex) {
-    cout<<__FILE__<<":"<<__LINE__<<" about to delete BASE PAIR " << basePairIndex <<" of "<<numBasePairs()<<endl; 
+    MMBLOG_FILE_FUNC_LINE(INFO, "about to delete BASE PAIR " << basePairIndex <<" of "<<numBasePairs()<<endl);
     (myBasePairVector).erase((myBasePairVector).begin()+basePairIndex);          
 }
 
@@ -63,8 +63,7 @@ void BasePairContainer::updateBasePair(int index, String ch1, int res1, String e
         myBasePairVector.insert(it, bi);
     }
     catch(const out_of_range& oor){
-        ErrorManager::instance << "BaseInteraction index " << index << " invalid for update." << endl;
-        ErrorManager::instance.treatError();
+        MMBLOG_FILE_FUNC_LINE(CRITICAL, "BaseInteraction index " << index << " invalid for update." << endl);
     }
     catch(const MMBException& mmbError){
         myBasePairVector.insert(it, original);
@@ -74,7 +73,7 @@ void BasePairContainer::updateBasePair(int index, String ch1, int res1, String e
 
 String BasePairContainer::getBasePairsStrings(){
     stringstream returnStr;
-    for(int i = 0; i < myBasePairVector.size(); i++){
+    for(size_t i = 0; i < myBasePairVector.size(); i++){
         returnStr << i << " " 
                      << myBasePairVector[i].FirstBPChain << " "
                      << myBasePairVector[i].FirstBPResidue.getResidueNumber() << " "
@@ -95,19 +94,16 @@ void BasePairContainer::validateBasePair(BiopolymerClassContainer & myBiopolymer
     myBiopolymerClassContainer.updBiopolymerClass(myBasePair.SecondBPChain).validateResidueID(myBasePair.SecondBPResidue);
     if (!((myBiopolymerClassContainer.updBiopolymerClass(myBasePair.FirstBPChain).biopolymerType ==  BiopolymerType::RNA) ||
           (myBiopolymerClassContainer.updBiopolymerClass(myBasePair.FirstBPChain).biopolymerType == BiopolymerType::DNA))) {
-        ErrorManager::instance <<__FILE__<<":"<<__LINE__<<": You have attempted to create a baseInteraction for a chain which is of type : "<<myBiopolymerClassContainer.updBiopolymerClass(myBasePair.FirstBPChain).biopolymerType<<" rather than of DNA or RNA."<<endl;
-        ErrorManager::instance.treatError();
+        MMBLOG_FILE_FUNC_LINE(CRITICAL, "You have attempted to create a baseInteraction for a chain which is of type : "<<myBiopolymerClassContainer.updBiopolymerClass(myBasePair.FirstBPChain).biopolymerType<<" rather than of DNA or RNA."<<endl);
     }
 
     if (!((myBiopolymerClassContainer.updBiopolymerClass(myBasePair.SecondBPChain).biopolymerType == BiopolymerType::RNA) ||
           (myBiopolymerClassContainer.updBiopolymerClass(myBasePair.SecondBPChain).biopolymerType == BiopolymerType::DNA))) {
-        ErrorManager::instance <<__FILE__<<":"<<__LINE__<<": You have attempted to create a baseInteraction for a chain which is of type : "<<myBiopolymerClassContainer.updBiopolymerClass(myBasePair.SecondBPChain).biopolymerType<<" rather than of DNA or RNA."<<endl;
-        ErrorManager::instance.treatError();
+        MMBLOG_FILE_FUNC_LINE(CRITICAL, "You have attempted to create a baseInteraction for a chain which is of type : "<<myBiopolymerClassContainer.updBiopolymerClass(myBasePair.SecondBPChain).biopolymerType<<" rather than of DNA or RNA."<<endl);
     }
     if ((myBasePair.FirstBPResidue == myBasePair.SecondBPResidue) &&
         (myBasePair.FirstBPChain == myBasePair.SecondBPChain)) {
-        ErrorManager::instance <<__FILE__<<":"<<__LINE__<<": You have attempted to create a baseInteraction between chain "<< myBasePair.FirstBPChain<< ", residue "<<myBasePair.FirstBPResidue.outString()<<" and itself.  This is not allowed!"<<endl;
-        ErrorManager::instance.treatError();
+        MMBLOG_FILE_FUNC_LINE(CRITICAL, "You have attempted to create a baseInteraction between chain "<< myBasePair.FirstBPChain<< ", residue "<<myBasePair.FirstBPResidue.outString()<<" and itself.  This is not allowed!"<<endl);
     }
 
     if(helicalStacking && 
@@ -116,12 +112,10 @@ void BasePairContainer::validateBasePair(BiopolymerClassContainer & myBiopolymer
        myBasePair.OrientationBP=="Cis")
     {
         if(hasWatsonCrickCisPair(myBasePair.FirstBPChain, myBasePair.FirstBPResidue)){
-            ErrorManager::instance <<__FILE__<<":"<<__LINE__<<": There is already one WatsonCrick/WatsonCrick/Cis base pair assigned to chain "<<myBasePair.FirstBPChain<<", residue "<<myBasePair.FirstBPResidue.outString()<<".  If you insist on this, please turn off setHelicalStacking . "<<endl;
-            ErrorManager::instance.treatError();
+            MMBLOG_FILE_FUNC_LINE(CRITICAL, "There is already one WatsonCrick/WatsonCrick/Cis base pair assigned to chain "<<myBasePair.FirstBPChain<<", residue "<<myBasePair.FirstBPResidue.outString()<<".  If you insist on this, please turn off setHelicalStacking . "<<endl);
         }
         if(hasWatsonCrickCisPair(myBasePair.SecondBPChain, myBasePair.SecondBPResidue)){
-            ErrorManager::instance <<__FILE__<<":"<<__LINE__<<": There is already one WatsonCrick/WatsonCrick/Cis base pair assigned to chain "<<myBasePair.SecondBPChain<<", residue "<<myBasePair.SecondBPResidue.outString()<<".  If you insist on this, please turn off setHelicalStacking . "<<endl;
-            ErrorManager::instance.treatError();
+            MMBLOG_FILE_FUNC_LINE(CRITICAL, "There is already one WatsonCrick/WatsonCrick/Cis base pair assigned to chain "<<myBasePair.SecondBPChain<<", residue "<<myBasePair.SecondBPResidue.outString()<<".  If you insist on this, please turn off setHelicalStacking . "<<endl);
         }
     }
 
@@ -178,16 +172,14 @@ bool BasePairContainer::hasWatsonCrickCisPair(String chainID ,ResidueID residueN
     } else if (numWatsonCrickPairs == 1) {
         return true; // one WC pair found for this chainID and residueNumber.
     } else {
-        ErrorManager::instance <<__FILE__<<":"<<__LINE__<<": There is more than one WatsonCrick/WatsonCrick/Cis base pair assigned to chain "<<chainID<<", residue "<<residueNumber.outString()<<".  If you insist on this, please turn off setHelicalStacking . "<<endl;
-        ErrorManager::instance.treatError();
+        MMBLOG_FILE_FUNC_LINE(CRITICAL, "There is more than one WatsonCrick/WatsonCrick/Cis base pair assigned to chain "<<chainID<<", residue "<<residueNumber.outString()<<".  If you insist on this, please turn off setHelicalStacking . "<<endl);
     }
 }
 
 const BaseInteraction BasePairContainer::getWatsonCrickCisPair(String chainID ,ResidueID residueNumber) { 
     // this also ensures that redundant WatsonCrick's don't exist.
     if (! hasWatsonCrickCisPair(chainID, residueNumber)) {
-        ErrorManager::instance <<__FILE__<<":"<<__LINE__<<": You have attempted to retrieve a baseInteraction for chain "<<chainID<<" residue "<<residueNumber.outString()<<" which doesn't exist. "<<endl;
-        ErrorManager::instance.treatError();
+        MMBLOG_FILE_FUNC_LINE(CRITICAL, "You have attempted to retrieve a baseInteraction for chain "<<chainID<<" residue "<<residueNumber.outString()<<" which doesn't exist. "<<endl);
     } else {
         for (int i = 0; i < numBasePairs(); i++) {
             if (  (getBasePair(i).FirstBPEdge.compare("WatsonCrick") == 0)  &&
@@ -201,8 +193,7 @@ const BaseInteraction BasePairContainer::getWatsonCrickCisPair(String chainID ,R
             }
         } // of for i
     } // of else
-    ErrorManager::instance <<__FILE__<<":"<<__LINE__<<": UNKNOWN ERROR -- shouldn't get here\n";
-    ErrorManager::instance.treatError();
+    MMBLOG_FILE_FUNC_LINE(CRITICAL, "UNKNOWN ERROR -- shouldn't get here" << endl);
 } // of method
 
 
@@ -217,8 +208,7 @@ const ResidueID BasePairContainer::getWatsonCrickCisPairingResidue(String chainI
               (myBasePair.SecondBPChain == chainID))  {
         return myBasePair.FirstBPResidue;
     } else {
-        ErrorManager::instance <<__FILE__<<":"<<__LINE__<<": Unexplained error! "<<endl;
-        ErrorManager::instance.treatError();
+        MMBLOG_FILE_FUNC_LINE(CRITICAL, "Unexplained error! "<<endl);
     }
 }
 
@@ -231,8 +221,7 @@ const String BasePairContainer::getWatsonCrickCisPairingChain(String chainID ,Re
               (myBasePair.SecondBPChain == chainID))  {
         return myBasePair.FirstBPChain;
     } else {
-        ErrorManager::instance <<__FILE__<<":"<<__LINE__<<": Unexplained error! "<<endl;
-        ErrorManager::instance.treatError();
+        MMBLOG_FILE_FUNC_LINE(CRITICAL, "Unexplained error! "<<endl);
     }
 }
 
@@ -240,8 +229,7 @@ const String BasePairContainer::getWatsonCrickCisPairingChain(String chainID ,Re
 // This means that it must interact with consecutive residues of the same or different chain.
 const ResidueID  BasePairContainer::getLastWatsonCrickCisPairingResidueOfRun(String chainID ,ResidueID firstResidueNumberInStack, BiopolymerClassContainer & myBiopolymerClassContainer) { 
     if (! hasWatsonCrickCisPair(  chainID,firstResidueNumberInStack) ){ 
-        ErrorManager::instance <<__FILE__<<":"<<__LINE__<<": The residue number you provided, "<< firstResidueNumberInStack.outString()<<" is not engaged in any WatsonCrick Cis interactions!  "<<endl;
-        ErrorManager::instance.treatError();
+        MMBLOG_FILE_FUNC_LINE(CRITICAL, "The residue number you provided, "<< firstResidueNumberInStack.outString()<<" is not engaged in any WatsonCrick Cis interactions!  "<<endl);
         // return firstResidueNumberInStack;
     }
             
@@ -259,12 +247,12 @@ const ResidueID  BasePairContainer::getLastWatsonCrickCisPairingResidueOfRun(Str
                     ResidueID    lastInteractingResidue =  getWatsonCrickCisPairingResidue(chainID, lastResidueNumberInStack);
                     String lastInteractingChain   =  getWatsonCrickCisPairingChain  (chainID, lastResidueNumberInStack);
 
-                    cout<<__FILE__<<":"<<__LINE__<<" firstInteractingChain = >"<<firstInteractingChain<<"< lastInteractingChain = >"<<lastInteractingChain<<"< "<<std::endl; 
+                    MMBLOG_FILE_FUNC_LINE(INFO, "firstInteractingChain = >"<<firstInteractingChain<<"< lastInteractingChain = >"<<lastInteractingChain<<"< "<<endl);
                     if (firstInteractingChain.compare(lastInteractingChain) != 0) {
-                        cout<<__FILE__<<":"<<__LINE__<<" Residue "<<lastResidueNumberInStack.outString()<<" of chain "<<chainID<<" is interacting with chain "<<lastInteractingChain<<" Residue "<<lastInteractingResidue.outString()<<endl;
-                        cout<<__FILE__<<":"<<__LINE__<<" Whereas  "<<firstResidueNumberInStack.outString()<<" of chain "<<chainID<<" is interacting with chain "<<firstInteractingChain<<" Residue "<<firstInteractingResidue.outString()<<endl;
-                        cout<<__FILE__<<":"<<__LINE__<<" Whereas the first residue of the stack, "<<firstResidueNumberInStack.outString()<<" of chain "<<chainID<<" was interacting with residue "<<firstInteractingResidue.outString()<<" of chain "<<firstInteractingChain<<endl;
-                        cout<<__FILE__<<":"<<__LINE__<<" Since the interacting chains are different, residue "<<lastResidueNumberInStack.outString() <<" of chain "<<chainID<<" is not part of the stack"<<endl;
+                        MMBLOG_FILE_FUNC_LINE(INFO, "Residue "<<lastResidueNumberInStack.outString()<<" of chain "<<chainID<<" is interacting with chain "<<lastInteractingChain<<" Residue "<<lastInteractingResidue.outString()<<endl);
+                        MMBLOG_FILE_FUNC_LINE(INFO, "Whereas  "<<firstResidueNumberInStack.outString()<<" of chain "<<chainID<<" is interacting with chain "<<firstInteractingChain<<" Residue "<<firstInteractingResidue.outString()<<endl);
+                        MMBLOG_FILE_FUNC_LINE(INFO, "Whereas the first residue of the stack, "<<firstResidueNumberInStack.outString()<<" of chain "<<chainID<<" was interacting with residue "<<firstInteractingResidue.outString()<<" of chain "<<firstInteractingChain<<endl);
+                        MMBLOG_FILE_FUNC_LINE(INFO, "Since the interacting chains are different, residue "<<lastResidueNumberInStack.outString() <<" of chain "<<chainID<<" is not part of the stack"<<endl);
                         return (myBiopolymerClass.decrementResidueID(lastResidueNumberInStack) );
                     }
 
@@ -273,7 +261,7 @@ const ResidueID  BasePairContainer::getLastWatsonCrickCisPairingResidueOfRun(Str
                     if ((myInteractingBiopolymerClass.difference(firstInteractingResidue , lastInteractingResidue) == myBiopolymerClass.difference (lastResidueNumberInStack , firstResidueNumberInStack)) &&
                         (lastInteractingChain.compare(firstInteractingChain)==0)){
                             // lastResidueNumberInStack is indeed still part of the stack.  Do nothing.
-                            cout<<__FILE__<<":"<<__LINE__<<" firstInteractingChain = "<<firstInteractingChain<<" lastInteractingChain = "<<lastInteractingChain<<std::endl; 
+                            MMBLOG_FILE_FUNC_LINE(INFO, "firstInteractingChain = "<<firstInteractingChain<<" lastInteractingChain = "<<lastInteractingChain<<endl);
                         } else {
                             // lastResidueNumberInStack is not part of the stack.  
                             return (myBiopolymerClass.decrementResidueID(lastResidueNumberInStack) );
@@ -284,66 +272,66 @@ const ResidueID  BasePairContainer::getLastWatsonCrickCisPairingResidueOfRun(Str
                     return myBiopolymerClass.decrementResidueID(lastResidueNumberInStack );
                 }
     } // of for lastResidueNumberInStack
-    ErrorManager::instance <<__FILE__<<":"<<__LINE__<<": Unexplained error! "<<endl;
-    ErrorManager::instance.treatError();
+    MMBLOG_FILE_FUNC_LINE(CRITICAL, "Unexplained error! "<<endl);
 } // of getLastWatsonCrickCisPairingResidueOfRun
 
+//void BasePairContainer::     addHelicalStackingInteractions(String chainID, ResidueID firstResidue, ResidueID lastResidue,BiopolymerClassContainer & myBiopolymerClassContainer, const LeontisWesthofClass & lhClass){
+/*void BasePairContainer::generateAorBFormNtCs(String chainID, ResidueID firstResidue, ResidueID lastResidue,BiopolymerClassContainer & myBiopolymerClassContainer, const LeontisWesthofClass & lhClass){
+    if ( myBiopolymerClassContainer.updBiopolymerClass(chainID).difference(lastResidue , firstResidue) <1) {
+        MMBLOG_FILE_FUNC_LINE(CRITICAL, "It's not possible to apply helical stacking interactions to a run of fewer than 2 residues! "<<endl);
+    }
+}*/
+
 void BasePairContainer::generateHelicalStackingInteractions(String chainID, ResidueID firstResidue, ResidueID lastResidue,BiopolymerClassContainer & myBiopolymerClassContainer, const LeontisWesthofClass & lhClass){
 
     if ( myBiopolymerClassContainer.updBiopolymerClass(chainID).difference(lastResidue , firstResidue) <1) {
-        ErrorManager::instance <<__FILE__<<":"<<__LINE__<<": It's not possible to apply helical stacking interactions to a run of fewer than 2 residues! "<<endl;
-        ErrorManager::instance.treatError();
+        MMBLOG_FILE_FUNC_LINE(CRITICAL, "It's not possible to apply helical stacking interactions to a run of fewer than 2 residues! "<<endl);
     }
     for (ResidueID i = firstResidue; i < lastResidue;myBiopolymerClassContainer.updBiopolymerClass(chainID).incrementResidueID( i) ) {
-           BaseInteraction myBasePair;
-           myBasePair.rotationCorrection1 = Rotation(0.0,UnitVec3(0,0,1));
-           myBasePair.rotationCorrection2 = Rotation(0.0,UnitVec3(0,0,1));
-           //myBasePair.BasePairIsTwoTransformForce = String("baseInteraction");
-           myBasePair.FirstBPChain    = chainID;
-           myBasePair.SecondBPChain   = chainID;
-           myBasePair.FirstBPResidue  =  i;
-           myBasePair.SecondBPResidue =  myBiopolymerClassContainer.updBiopolymerClass(chainID).incrementResidueID( i);
-           myBiopolymerClassContainer.updBiopolymerClass(chainID).decrementResidueID( i);
-           if      (myBiopolymerClassContainer.updBiopolymerClass(chainID).getBiopolymerType() == BiopolymerType::RNA) 
-           {
-               myBasePair.FirstBPEdge     = "HelicalStackingA3";
-               myBasePair.SecondBPEdge    = "HelicalStackingA5";
-           } else if (myBiopolymerClassContainer.updBiopolymerClass(chainID).getBiopolymerType() == BiopolymerType::DNA )
-           {
-               myBasePair.FirstBPEdge     = "HelicalStackingB3";
-               myBasePair.SecondBPEdge    = "HelicalStackingB5";
-           } else {
-               ErrorManager::instance <<__FILE__<<":"<<__LINE__<<": Invalid biopolymerType: "<< myBiopolymerClassContainer.updBiopolymerClass(chainID).getBiopolymerType() <<endl;
-               ErrorManager::instance.treatError();
-           }
-           myBasePair.OrientationBP = "Cis";
-           //myBasePair.BasePairPriority = 1;
-
-           addBasePair( myBiopolymerClassContainer,lhClass,myBasePair, true); 
+        BaseInteraction myBasePair;
+        myBasePair.rotationCorrection1 = Rotation(0.0,UnitVec3(0,0,1));
+        myBasePair.rotationCorrection2 = Rotation(0.0,UnitVec3(0,0,1));
+        myBasePair.FirstBPChain    = chainID;
+        myBasePair.SecondBPChain   = chainID;
+        myBasePair.FirstBPResidue  =  i;
+        myBasePair.SecondBPResidue =  myBiopolymerClassContainer.updBiopolymerClass(chainID).incrementResidueID( i);
+        myBiopolymerClassContainer.updBiopolymerClass(chainID).decrementResidueID( i);
+        if      (myBiopolymerClassContainer.updBiopolymerClass(chainID).getBiopolymerType() == BiopolymerType::RNA) 
+        {
+            myBasePair.FirstBPEdge     = "HelicalStackingA3";
+            myBasePair.SecondBPEdge    = "HelicalStackingA5";
+        } else if (myBiopolymerClassContainer.updBiopolymerClass(chainID).getBiopolymerType() == BiopolymerType::DNA )
+        {
+            myBasePair.FirstBPEdge     = "HelicalStackingB3";
+            myBasePair.SecondBPEdge    = "HelicalStackingB5";
+        } else {
+            MMBLOG_FILE_FUNC_LINE(CRITICAL, "Invalid biopolymerType: "<< myBiopolymerClassContainer.updBiopolymerClass(chainID).getBiopolymerType() <<endl);
+        }
+        myBasePair.OrientationBP = "Cis";
+        addBasePair( myBiopolymerClassContainer,lhClass,myBasePair, true); 
     }
     
 }
 
 // Add helical stacking interactions for all runs of Watson-Crick base pairs, beyond some minimum lenght
 
-void BasePairContainer::addHelicalStacking(BiopolymerClassContainer & myBiopolymerClassContainer, const LeontisWesthofClass & lhClass){
-    cout<<__FILE__<<":"<<__FUNCTION__<<":"<<__LINE__<<" Running addHelicalStacking  "<<endl;
-    for (int i = 0; i < myBiopolymerClassContainer.getNumBiopolymers(); i++) {
-        //cout<<__FILE__<<":"<<__FUNCTION__<<":"<<__LINE__<<" So far we have "<<numBasePairs() <<" baseInteraction's.  They are: "<<endl;
-        //printBasePairs();
+void BasePairContainer::addHelicalStacking(BiopolymerClassContainer & myBiopolymerClassContainer, const LeontisWesthofClass & lhClass, const  NTC_PAR_Class & ntc_par_class , NTC_Class_Container  & my_ntc_class_container){
+    MMBLOG_FILE_FUNC_LINE(INFO, "Running addHelicalStacking  "<<endl);
+    for (auto i = 0; i < myBiopolymerClassContainer.getNumBiopolymers(); i++) {
+        //MMBLOG_FILE_FUNC_LINE(" So far we have "<<numBasePairs() <<" baseInteraction's.  They are: "<<endl;
         BiopolymerClass & myBiopolymerClass = myBiopolymerClassContainer.updBiopolymerClass(i);
         String myChainID = myBiopolymerClass.getChainID();
-        cout<<__FILE__<<":"<<__FUNCTION__<<":"<<__LINE__<<" Running addHelicalStacking for chain "<<myChainID<<endl;
+        MMBLOG_FILE_FUNC_LINE(INFO, "Running addHelicalStacking for chain "<<myChainID<<endl);
         //myResidueNumber counts down chain i from the first to last residue number, looking for stretches of chain i to which it can apply helical stacking runs.  at the end of each stacking run, it increments to one residue after the last residue of the run.
-        //for (ResidueID myResidue = myBiopolymerClass.getFirstResidueID(); myResidue <=  myBiopolymerClass.getLastResidueID(); myBiopolymerClass.incrementResidueID(myResidue)){
         ResidueID myResidue = myBiopolymerClass.getFirstResidueID(); 
         while  ( myResidue !=  myBiopolymerClass.getLastResidueID()){
-            cout<<__FILE__<<":"<<__FUNCTION__<<":"<<__LINE__<<" Checking myResidue "<<myResidue.outString()<<" vs. myBiopolymerClass.getLastResidueID() = "<<myBiopolymerClass.getLastResidueID().outString()<<std::endl;
+            MMBLOG_FILE_FUNC_LINE(INFO, "Checking myResidue "<<myResidue.outString()<<" vs. myBiopolymerClass.getLastResidueID() = "<<myBiopolymerClass.getLastResidueID().outString()<<endl);
             if ( hasWatsonCrickCisPair(myChainID,myResidue) ){ 
                 ResidueID lastPairingResidue = getLastWatsonCrickCisPairingResidueOfRun(myChainID,myResidue,myBiopolymerClassContainer);
-                cout<<__FILE__<<":"<<__FUNCTION__<<":"<<__LINE__<<" Generating stacking interactions from "<<myResidue.outString()<<" to "<<lastPairingResidue.outString()<<endl;
+                MMBLOG_FILE_FUNC_LINE(INFO, "Generating stacking interactions from "<<myResidue.outString()<<" to "<<lastPairingResidue.outString()<<endl);
                 if ( myBiopolymerClass.difference (lastPairingResidue , myResidue) > 1){ // if we have at least 3BP in the helix.  increase this if you wish, but minimum is zero.
                     generateHelicalStackingInteractions(myChainID,myResidue,lastPairingResidue,myBiopolymerClassContainer, lhClass) ;
+                    my_ntc_class_container.generateAorBFormNtCs( myBiopolymerClassContainer, myChainID, myResidue, lastPairingResidue, 0.5 , ntc_par_class);
                 }
                 if (lastPairingResidue <  myBiopolymerClass.getLastResidueID()) {
                     myResidue = myBiopolymerClass.incrementResidueID(lastPairingResidue) ; // continue the outer loop after the just-discovered stacking run.
@@ -351,8 +339,7 @@ void BasePairContainer::addHelicalStacking(BiopolymerClassContainer & myBiopolym
                 }
                 else if (lastPairingResidue ==  myBiopolymerClass.getLastResidueID()) break ; // we've already set all helical stackings for this chain.
                 else { // lastPairingResidue > myBiopolymerClass.getLastResidueID() .. can't happen!
-                    ErrorManager::instance <<__FILE__<<":"<<__FUNCTION__<<":"<<__LINE__<<" Unexplained error!"<<endl;
-                    ErrorManager::instance.treatError();
+                    MMBLOG_FILE_FUNC_LINE(CRITICAL, "Unexplained error!"<<endl);
                 }
             } else if (myResidue ==  myBiopolymerClass.getLastResidueID()) {
                 break; // we're at the last residue of the chain
@@ -361,33 +348,22 @@ void BasePairContainer::addHelicalStacking(BiopolymerClassContainer & myBiopolym
                 myResidue = myBiopolymerClass.incrementResidueID(myResidue); // increment myResidue
                 if (myResidue ==  myBiopolymerClass.getLastResidueID()) break ; // If we've just incremented to the end of the chain, we're done here.
             } 
-            // inequalities no longer supported for ResidueID
-            /*else { // shouldn't happen!  myResidue >  myBiopolymerClass.getLastResidueID()
-                ErrorManager::instance <<__FILE__<<":"<<__FUNCTION__<<":"<<__LINE__<<" Unexplained error!"<<endl;
-                ErrorManager::instance.treatError();
-            }*/
 
             if ( myResidue ==  myBiopolymerClass.getLastResidueID()) { // this should have been caught above.
-                ErrorManager::instance <<__FILE__<<":"<<__FUNCTION__<<":"<<__LINE__<<" Unexplained error!"<<endl;
-                ErrorManager::instance.treatError();
+                MMBLOG_FILE_FUNC_LINE(CRITICAL, "Unexplained error!"<<endl);
             }
-            // Inequalities no longer supported for ResidueID
-            /*if ( myResidue >   myBiopolymerClass.getLastResidueID()) { // this should have been caught above.
-                ErrorManager::instance <<__FILE__<<":"<<__FUNCTION__<<":"<<__LINE__<<" Unexplained error!"<<endl;
-                ErrorManager::instance.treatError();
-            }*/
             
         } // of for myResidue
     } // of for i
-    cout<<__FILE__<<":"<<__FUNCTION__<<":"<<__LINE__<<" Done adding helical stackings. So far we have "<<numBasePairs() <<" baseInteraction's.  They are: "<<endl;
+    MMBLOG_FILE_FUNC_LINE(INFO, "Done adding helical stackings. So far we have "<<numBasePairs() <<" baseInteraction's.  They are: "<<endl);
     printBasePairs();
 } // of addHelicalStacking
 
 
 void BasePairContainer::printBasePairs() {
-    cout<<__FILE__<<":"<<__LINE__<<" Printing all base pairs:"<<endl;
-    for (int i = 0; i < numBasePairs(); i++) {
-        cout<<__FILE__<<":"<<__LINE__<<" "<<getBasePair(i).FirstBPChain<<" "<<getBasePair(i).FirstBPResidue.outString()<<" "<<   getBasePair(i).FirstBPEdge<<" "<<getBasePair(i).SecondBPChain<<" "<<getBasePair(i).SecondBPResidue.outString()<<" "<<   getBasePair(i).SecondBPEdge<<" "<<  getBasePair(i).OrientationBP<<endl;
+    MMBLOG_FILE_FUNC_LINE(INFO, "Printing all base pairs:"<<endl);
+    for (auto i = 0; i < numBasePairs(); i++) {
+        MMBLOG_FILE_FUNC_LINE(INFO, getBasePair(i).FirstBPChain<<" "<<getBasePair(i).FirstBPResidue.outString()<<" "<<   getBasePair(i).FirstBPEdge<<" "<<getBasePair(i).SecondBPChain<<" "<<getBasePair(i).SecondBPResidue.outString()<<" "<<   getBasePair(i).SecondBPEdge<<" "<<  getBasePair(i).OrientationBP<<endl);
     }
 }
 
@@ -397,7 +373,7 @@ void BasePairContainer::setBasePairSatisfied(int basePairIndex ,bool isSatisfied
 
 vector<int> BasePairContainer::getSatisfiedBasePairs(){
     vector<int> bps;
-    for (int i = 0; i < numBasePairs(); i++) {
+    for (auto i = 0; i < numBasePairs(); i++) {
         if(getBasePair(i).basePairSatisfied){
             bps.push_back(i);
         }
