@@ -16,7 +16,7 @@
 
 void ContactContainer::clear(){
     residueStretchVector.clear();
-    cout<<__FILE__<<":"<<__LINE__<<" Just cleared residueStretchVector .. this now contains "<<numContacts()<<" contacts "<<endl;
+    MMBLOG_FILE_FUNC_LINE(INFO, "Just cleared residueStretchVector .. this now contains "<<numContacts()<<" contacts "<<endl);
     contactWithinVector.clear();
 
 }
@@ -31,9 +31,8 @@ void ContactContainer::validateContact(ContactStretch myContactStretch, Biopolym
 	(!(myBiopolymerClassContainer.updBiopolymerClass((myContactStretch.getChain())).getBiopolymerType()  == BiopolymerType::DNA))
 	) &&
        (((myContactStretch).ContactScheme).compare("SelectedAtoms") == 0))  {
-	ErrorManager::instance <<__FILE__<<":"<<__LINE__<<" The SelectedAtoms sterics can only be applied to RNA or DNA chains.  You are attempting to apply them to a "<< myBiopolymerClassContainer.updBiopolymerClass((myContactStretch.getChain())).getBiopolymerType() <<" chain. "<<endl;
-	ErrorManager::instance.treatError();
-    };
+        MMBLOG_FILE_FUNC_LINE(CRITICAL, "The SelectedAtoms sterics can only be applied to RNA or DNA chains.  You are attempting to apply them to a "<< myBiopolymerClassContainer.updBiopolymerClass((myContactStretch.getChain())).getBiopolymerType() <<" chain. "<<endl);
+    }
 
 
 	if ((myBiopolymerClassContainer.updBiopolymerClass((myContactStretch.getChain())).getBiopolymerType()  == BiopolymerType::Protein) && myBiopolymerClassContainer.updBiopolymerClass((myContactStretch.getChain())).getProteinCapping())
@@ -41,19 +40,17 @@ void ContactContainer::validateContact(ContactStretch myContactStretch, Biopolym
 	else {myEndCapsOn = false;} // importantly, myEndCapsOn is always false for RNA
 
 	if (((myContactStretch).ContactScheme).compare("ExcludedVolume") ==0 ){
-	    ErrorManager::instance <<__FILE__<<":"<<__LINE__<<" : ExcludedVolume is no longer a supported contact type."<<endl;ErrorManager::instance.treatError();
+	    MMBLOG_FILE_FUNC_LINE(CRITICAL, "ExcludedVolume is no longer a supported contact type."<<endl);
 	}
 
 
 
 
 	 else if (((myContactStretch).ContactScheme).compare("RNABackboneSterics") ==0 ){
-	     ErrorManager::instance <<__FILE__<<":"<<__LINE__<<" RNABackboneSterics is no longer supported. "<<endl;//s.  You are attempting to apply them to a non-RNA chain. "<<endl;
-	     ErrorManager::instance.treatError();
+	     MMBLOG_FILE_FUNC_LINE(CRITICAL, "RNABackboneSterics is no longer supported. "<<endl);
 
 	     if (!(myBiopolymerClassContainer.updBiopolymerClass((myContactStretch.getChain())).getBiopolymerType()  == BiopolymerType::RNA)) {
-		 ErrorManager::instance <<__FILE__<<":"<<__LINE__<<" The RNABackboneSterics can only be applied to RNA chains.  You are attempting to apply them to a non-RNA chain. "<<endl;
-		 ErrorManager::instance.treatError();
+            MMBLOG_FILE_FUNC_LINE(CRITICAL, "The RNABackboneSterics can only be applied to RNA chains.  You are attempting to apply them to a non-RNA chain. "<<endl);
 		 }
 	} else {
 		    // everything is OK!
@@ -71,16 +68,14 @@ void ContactContainer::pushContactWithin ( ContactWithin contactWithin, Biopolym
 
 void ContactContainer::deleteContactWithin(int id){
     if(id < 0 || id >= contactWithinVector.size()){
-        ErrorManager::instance <<__FILE__<<":"<<__LINE__<<": you tried to delete a non existing Contact." << endl;
-        ErrorManager::instance.treatError();
+        MMBLOG_FILE_FUNC_LINE(CRITICAL, "you tried to delete a non existing Contact." << endl);
     }
     contactWithinVector.erase(contactWithinVector.begin()+id);
 }
 
 void ContactContainer::updateContactWithin(int id, String chainID, int resID, double radius, String contactScheme, BiopolymerClassContainer & myBiopolymerClassContainer){
     if(id < 0 || id >= contactWithinVector.size()){
-        ErrorManager::instance <<__FILE__<<":"<<__LINE__<<": you tried to update a non existing Contact." << endl;
-        ErrorManager::instance.treatError();
+        MMBLOG_FILE_FUNC_LINE(CRITICAL, "you tried to update a non existing Contact." << endl);
     }
     ContactWithin & newContactWithin = contactWithinVector[id];
     newContactWithin.Chain = chainID;
@@ -108,7 +103,7 @@ void ContactContainer::listDistances ( BiopolymerClassContainer & myBiopolymerCl
 			partnerBiopolymerClass.calcAtomLocationInGroundFrame  (state, j, partnerBiopolymerClass.getRepresentativeAtomName())
 			- primaryBiopolymerClass.calcAtomLocationInGroundFrame(state, h, primaryBiopolymerClass.getRepresentativeAtomName())
 			).norm();
-		    cout<<__FILE__<<":"<<__LINE__<<" Distance between chain "<<primaryBiopolymerClass.getChainID()<<" , residue "<<h.outString()<<" , atom "<<primaryBiopolymerClass.getRepresentativeAtomName()<<" and chain "<<partnerBiopolymerClass.getChainID()<<" residue "<<j.outString()<<" atom "<<partnerBiopolymerClass.getRepresentativeAtomName() <<" = "<<myDistance<<endl;
+		    MMBLOG_FILE_FUNC_LINE(INFO, "Distance between chain "<<primaryBiopolymerClass.getChainID()<<" , residue "<<h.outString()<<" , atom "<<primaryBiopolymerClass.getRepresentativeAtomName()<<" and chain "<<partnerBiopolymerClass.getChainID()<<" residue "<<j.outString()<<" atom "<<partnerBiopolymerClass.getRepresentativeAtomName() <<" = "<<myDistance<<endl);
 		} // of for j
 	    } // of for i
       } // of for h
@@ -128,13 +123,13 @@ void ContactContainer::createContactsWithin ( BiopolymerClassContainer & myBiopo
         return;
     }
     vector<MMBAtomInfo> concatenatedAtomInfoVector = myBiopolymerClassContainer.getConcatenatedAtomInfoVector(state,true);
-    cout << "ContactContainer: caching neighborList"<<endl;
+    MMBLOG_FILE_FUNC_LINE(INFO, "ContactContainer: caching neighborList"<<endl);
     OpenMM::NeighborList neighborList = myBiopolymerClassContainer.getNeighborList(concatenatedAtomInfoVector, maxRadius); 
     myBiopolymerClassContainer.setNeighborsFromList(concatenatedAtomInfoVector, neighborList, maxRadius);
     for (int h = 0; h < (int)contactWithinVector.size(); h++)
     {
-        cout<<__FILE__<<":"<<__LINE__<<" Starting to apply contacts within "<<contactWithinVector[h].Radius<<" nm of chain "<<contactWithinVector[h].Chain<<" residue "<<contactWithinVector[h].Residue.outString()<<endl;
-        cout<<__FILE__<<":"<<__LINE__<<" Note that in MMB 2.10 and earlier, we took this radius in Å.  We are going back to nm for consistency, with apologies for the confusion."<<endl;
+        MMBLOG_FILE_FUNC_LINE(DEBUG, "Starting to apply contacts within "<<contactWithinVector[h].Radius<<" nm of chain "<<contactWithinVector[h].Chain<<" residue "<<contactWithinVector[h].Residue.outString()<<endl);
+        MMBLOG_FILE_FUNC_LINE(DEBUG, "Note that in MMB 2.10 and earlier, we took this radius in Å.  We are going back to nm for consistency, with apologies for the confusion."<<endl);
         // vector< pair<const BiopolymerClass*, const ResidueID*> > residuesWithin = myBiopolymerClassContainer.getResiduesWithin(contactWithinVector[h].Chain, contactWithinVector[h].Residue, contactWithinVector[h].Radius, state, &neighborList);
 
         // vector< pair<const BiopolymerClass*, const ResidueID*> >::iterator it;
@@ -153,49 +148,48 @@ void ContactContainer::createContactsWithin ( BiopolymerClassContainer & myBiopo
                     // Skip residues in unactive chains
                     if(myBiopolymerClass.getActivePhysics() == false)
                         continue;
-                    cout<<__FILE__<<":"<<__LINE__<<" distance is less than "<<contactWithinVector[h].Radius<<", checking if contact already exists : ";
+                    MMBLOG_FILE_FUNC_LINE(DEBUG, "distance is less than "<<contactWithinVector[h].Radius<<", checking if contact already exists : ");
                     ContactStretch myContact;
                     myContact.setChain (myBiopolymerClass.getChainID());
                     myContact.setStartResidue((*itAtomPointer)->residueID);
                     myContact.setEndResidue ((*itAtomPointer)->residueID);
                     myContact.ContactScheme = contactWithinVector[h].ContactScheme;
-                    cout<<__FILE__<<":"<<__LINE__<<" result : "<<hasSharedContact(myContact)<<endl;
+                    MMBLOG_FILE_FUNC_LINE(DEBUG, "result : "<<hasSharedContact(myContact)<<endl);
                     if (! (hasSharedContact(myContact))) {
-                        cout<<__FILE__<<":"<<__LINE__<<" Adding contact : ";
+                        MMBLOG_FILE_FUNC_LINE(DEBUG, "Adding contact : ");
                         printContact(myContact);
                         addContactToVector(myContact, myBiopolymerClassContainer);
                     } else if (hasSharedContact(myContact) ) {
-                        cout<<__FILE__<<":"<<__LINE__<<" Not adding contact : ";
+                        MMBLOG_FILE_FUNC_LINE(DEBUG, "Not adding contact : ");
                         printContact(myContact);
                     } else {  
-                        ErrorManager::instance <<__FILE__<<":"<<__LINE__<<" Unexplained error!"<<endl;
-                        ErrorManager::instance.treatError();
+                        MMBLOG_FILE_FUNC_LINE(CRITICAL, "Unexplained error!"<<endl);
                     }
-                    cout<<__FILE__<<":"<<__LINE__<<endl;//" result : "<<hasSharedContact(myContact)<<endl;
+                    MMBLOG_FILE_FUNC_LINE(DEBUG, endl);//" result : "<<hasSharedContact(myContact)<<endl;
                 }
             }
         }
     }
-    cout<<__FILE__<<":"<<__LINE__<<" done with createContactsWithin .. at this stage, the list of contacts is:"<<endl;
-    //cout<<__FILE__<<":"<<__LINE__<<" Preparing to print all "<<numContacts()<<" contacts "<<endl;
+    MMBLOG_FILE_FUNC_LINE(INFO, "done with createContactsWithin .. at this stage, the list of contacts is:"<<endl);
+    //MMBLOG_FILE_FUNC_LINE(" Preparing to print all "<<numContacts()<<" contacts "<<endl;
     printContacts();
-    cout<<__FILE__<<":"<<__LINE__<<" done with createContactsWithin .. moving on .."<<endl;
+    MMBLOG_FILE_FUNC_LINE(INFO, "done with createContactsWithin .. moving on .."<<endl);
 } // of method
 #endif
 
 void ContactContainer::printContact(ContactStretch contactStretch)  {
-        cout<<__FILE__<<":"<<__LINE__<<" Contact scheme = "<<contactStretch.ContactScheme<<" chain= "<<contactStretch.getChain()<<" from residue "<<contactStretch.getStartResidue().outString()<<" to "<<contactStretch.getEndResidue().outString()<<endl;
+        MMBLOG_FILE_FUNC_LINE(INFO, "Contact scheme = "<<contactStretch.ContactScheme<<" chain= "<<contactStretch.getChain()<<" from residue "<<contactStretch.getStartResidue().outString()<<" to "<<contactStretch.getEndResidue().outString()<<endl);
 }
 void ContactContainer::printContact(int contactIndex) {
 	ContactStretch contactStretch = getResidueStretch(contactIndex );
           
-        cout<<__FILE__<<":"<<__LINE__<<" Contact "<<contactIndex<<" ";//scheme = "<<contactStretch.ContactScheme<<" chain= "<<contactStretch.getChain()<<" from residue "<<contactStretch.getStartResidue().outString()<<" to "<<contactStretch.getEndResidue().outString()<<endl;
+        MMBLOG_FILE_FUNC_LINE(INFO, "Contact "<<contactIndex<<" ");//scheme = "<<contactStretch.ContactScheme<<" chain= "<<contactStretch.getChain()<<" from residue "<<contactStretch.getStartResidue().outString()<<" to "<<contactStretch.getEndResidue().outString()<<endl;
         printContact(contactStretch);
 }
 
 
 void ContactContainer::printContacts(){
-    cout<<__FILE__<<":"<<__LINE__<<" Preparing to print all "<<numContacts()<<" contacts "<<endl;
+    MMBLOG_FILE_FUNC_LINE(INFO, "Preparing to print all "<<numContacts()<<" contacts "<<endl);
     for (int i = 0; i < numContacts(); i++) {
         printContact(i);
     }
@@ -229,8 +223,7 @@ for (int q=0;q<numContacts();q++)
 	(!(myBiopolymerClassContainer .updBiopolymerClass((myContactStretch.getChain())).getBiopolymerType()  == BiopolymerType::RNA))                &&
 	(!(myBiopolymerClassContainer .updBiopolymerClass((myContactStretch.getChain())).getBiopolymerType()  == BiopolymerType::DNA))
 	) &&                (((myContactStretch).ContactScheme).compare("SelectedAtoms") == 0))  {
-	ErrorManager::instance <<__FILE__<<":"<<__LINE__<<" The SelectedAtoms sterics can only be applied to RNA or DNA chains.  You are attempting to apply them to a "<< myBiopolymerClassContainer .updBiopolymerClass((myContactStretch.getChain())).getBiopolymerType() <<" chain. "<<endl;
-	ErrorManager::instance.treatError();
+        MMBLOG_FILE_FUNC_LINE(CRITICAL, "The SelectedAtoms sterics can only be applied to RNA or DNA chains. You are attempting to apply them to a "<< myBiopolymerClassContainer .updBiopolymerClass((myContactStretch.getChain())).getBiopolymerType() <<" chain. "<<endl);
     };
 
 
@@ -239,12 +232,11 @@ for (int q=0;q<numContacts();q++)
     else {myEndCapsOn = false;} // importantly, myEndCapsOn is always false for RNA
 
     if ((myContactStretch.ContactScheme).compare("ExcludedVolume") ==0 ){
-	ErrorManager::instance <<__FILE__<<":"<<__LINE__<<" : ExcludedVolume is no longer a supported contact type."<<endl;ErrorManager::instance.treatError();
+        MMBLOG_FILE_FUNC_LINE(CRITICAL, "ExcludedVolume is no longer a supported contact type."<<endl);
     }
 
      else if ((myContactStretch.ContactScheme).compare("RNABackboneSterics") ==0 ){
-	 ErrorManager::instance <<__FILE__<<":"<<__LINE__<<" RNABackboneSterics is no longer supported. "<<endl;//s.  You are attempting to apply them to a non-RNA chain. "<<endl;
-	 ErrorManager::instance.treatError();
+        MMBLOG_FILE_FUNC_LINE(CRITICAL, "RNABackboneSterics is no longer supported. "<<endl);//s.  You are attempting to apply them to a non-RNA chain. "<<endl;
      }
      else if ((myContactStretch.ContactScheme).compare("AllHeavyAtomSterics") ==0 )
 	myBiopolymerClassContainer.updBiopolymerClass(myContactStretch.getChain()).addGeneralSterics(contacts,contactSetLargeSpheres ,hcLargeSpheres, matter,excludedVolumeRadius, excludedVolumeStiffness , (myContactStretch).getStartResidue(),(myContactStretch).getEndResidue(), myEndCapsOn, false );
@@ -257,7 +249,7 @@ for (int q=0;q<numContacts();q++)
     }   
 
 } // of for q  
-cout<<__FILE__<<" : "<<__LINE__<<" Have applied "<<contacts.getNumBodies(contactSetLargeSpheres)<<" contact spheres to atoms."<<endl;
+    MMBLOG_FILE_FUNC_LINE(INFO, "Have applied "<<contacts.getNumBodies(contactSetLargeSpheres)<<" contact spheres to atoms."<<endl);
 } // of method
 
 
@@ -265,16 +257,16 @@ cout<<__FILE__<<" : "<<__LINE__<<" Have applied "<<contacts.getNumBodies(contact
 
 void ContactContainer::addContactToVector(ContactStretch myContactStretch, BiopolymerClassContainer & myBiopolymerClassContainer) {
     validateContact(myContactStretch, myBiopolymerClassContainer); 
-    ResidueStretchContainer<ContactStretch>::addResidueStretchToVector  (myContactStretch );
+    ResidueStretchContainer<ContactStretch>::addStretch  (myContactStretch );
     printContact(myContactStretch);
  //    getNumResidueStretches();
- //    cout<<__FILE__<<":"<<__LINE__<<" Just added a contact to the residue stretch vector.  Now have "<<numContacts()<<" contacts "<<endl;
+ //    MMBLOG_FILE_FUNC_LINE(" Just added a contact to the residue stretch vector.  Now have "<<numContacts()<<" contacts "<<endl;
  //    int myInt = getNumResidueStretches();
  //    myInt --;
 
 	// ContactStretch contactStretch = getResidueStretch(myInt );
- //        cout<<__FILE__<<":"<<__LINE__<< " from residue "<<contactStretch.getStartResidue().outString()<<" to "<<contactStretch.getEndResidue().outString()<<endl;
- //        cout<<__FILE__<<":"<<__LINE__<<   " Contact "<<myInt<<" scheme = "<<contactStretch.ContactScheme;//<<" chain= "<<contactStretch.getChain()<<" from residue "<<contactStretch.getStartResidue().outString()<<" to "<<contactStretch.getEndResidue().outString()<<endl;
+ //        MMBLOG_FILE_FUNC_LINE( " from residue "<<contactStretch.getStartResidue().outString()<<" to "<<contactStretch.getEndResidue().outString()<<endl;
+ //        MMBLOG_FILE_FUNC_LINE(   " Contact "<<myInt<<" scheme = "<<contactStretch.ContactScheme;//<<" chain= "<<contactStretch.getChain()<<" from residue "<<contactStretch.getStartResidue().outString()<<" to "<<contactStretch.getEndResidue().outString()<<endl;
  //        printContact(contactStretch);
 
  //    printContact(myInt);
@@ -283,8 +275,7 @@ void ContactContainer::addContactToVector(ContactStretch myContactStretch, Biopo
 
 void ContactContainer::deleteContact(int id){
     if(id < 0 || id >= residueStretchVector.size()){
-        ErrorManager::instance <<__FILE__<<":"<<__LINE__<<": you tried to delete a non existing Contact." << endl;
-        ErrorManager::instance.treatError();
+        MMBLOG_FILE_FUNC_LINE(CRITICAL, "you tried to delete a non existing Contact." << endl);
     }
     residueStretchVector.erase(residueStretchVector.begin()+id);
 }
@@ -292,8 +283,7 @@ void ContactContainer::updateContact(int id, string myChain, int myStartResidue,
                                      int myEndResidue, string myContactScheme, 
                                      BiopolymerClassContainer & myBiopolymerClassContainer){
     if(id < 0 || id >= residueStretchVector.size()){
-        ErrorManager::instance <<__FILE__<<":"<<__LINE__<<": you tried to update a non existing Contact." << endl;
-        ErrorManager::instance.treatError();
+        MMBLOG_FILE_FUNC_LINE(CRITICAL, "you tried to update a non existing Contact." << endl);
     }
     ContactStretch newStretch;
     newStretch.setChain(myChain);
@@ -311,7 +301,7 @@ ContactStretch ContactContainer::getContact(int myContactIndex ) {
 
 
 int ContactContainer::numContacts(){
-    //cout<<__FILE__<<":"<<__LINE__<<" num contacts = "<<getNumResidueStretches()<<endl;
+    //MMBLOG_FILE_FUNC_LINE(" num contacts = "<<getNumResidueStretches()<<endl;
     return getNumResidueStretches();
     //return residueStretchVector.size();           
 };
@@ -325,16 +315,14 @@ bool  ContactContainer::hasSharedContact(String chainID, ResidueID startResidueI
             ((tempContactStretch.getStartResidue() <= endResidueID)   && (tempContactStretch.getEndResidue() >= endResidueID) ||   // the supplied end residue is in the range of this ContactStretch (with index $i).
              (tempContactStretch.getStartResidue() <= startResidueID) && (tempContactStretch.getEndResidue() >= startResidueID)) // the supplied start residue is in the range of this ContactStretch (with index $i).
             ) {
-            cout<<__FILE__<<":"<<__LINE__<<" The stretch of residues you proposed (chain "<<chainID<<" residues "<<startResidueID.outString()<<" to "<< endResidueID.outString()<<" overlaps with an existing stretch, from "<<tempContactStretch.getStartResidue().outString()<<" to "<<tempContactStretch.getEndResidue().outString()<<". "<<endl;  
+            MMBLOG_FILE_FUNC_LINE(DEBUG, "The stretch of residues you proposed (chain "<<chainID<<" residues "<<startResidueID.outString()<<" to "<< endResidueID.outString()<<" overlaps with an existing stretch, from "<<tempContactStretch.getStartResidue().outString()<<" to "<<tempContactStretch.getEndResidue().outString()<<". "<<endl);
             return true  ;
-            ErrorManager::instance <<__FILE__<<":"<<__LINE__<<" Unexplained error!"<<endl;
-            ErrorManager::instance.treatError(); // should never get to this point
+            MMBLOG_FILE_FUNC_LINE(CRITICAL, " Unexplained error!"<<endl);
         }
     }
-    cout<<__FILE__<<":"<<__LINE__<<" The stretch of residues you proposed (chain "<<chainID<<" residues "<<startResidueID.outString()<<" to "<< endResidueID.outString()<<" does not overlap with any existing stretch"<<endl;
+    MMBLOG_FILE_FUNC_LINE(DEBUG, "The stretch of residues you proposed (chain "<<chainID<<" residues "<<startResidueID.outString()<<" to "<< endResidueID.outString()<<" does not overlap with any existing stretch"<<endl);
     return (false);
-    ErrorManager::instance <<__FILE__<<":"<<__LINE__<<" Unexplained error!"<<endl;
-    ErrorManager::instance.treatError(); // should never get to this point
+    MMBLOG_FILE_FUNC_LINE(CRITICAL, "Unexplained error!"<<endl);
 };
 
 bool  ContactContainer::hasSharedContact(ContactStretch contactStretch)  {
