@@ -20,7 +20,7 @@
  //#include "SimTKsimbody_aux.h"
 
 #include "ParameterReader.h"
-#include "ErrorManager.h"
+#include "MMBLogger.h"
 #include "Repel.h"
 #include "ParameterReader_wrapper.h"
 
@@ -28,11 +28,6 @@ using namespace std;
 
 extern "C" {
 
-#ifdef _WIN32
-    ErrorManager* ErrorManager::p_instance = new ErrorManager(cerr);
-    ErrorManager & ErrorManager::instance(*ErrorManager::p_instance);
-#endif
-
     /***********************************************************************************/
     /**
     * Description of a Biopolymer sequence.
